@@ -21,13 +21,3 @@ try:
     from .version import githash as __githash__
 except ImportError:
     __githash__ = ''
-
-
-if not _ASTROPY_SETUP_:  # noqa
-    import os
-
-    # Create the test function for self test
-    from astropy.tests.runner import TestRunner
-    test = TestRunner.make_test_runner_in(os.path.dirname(__file__))
-    test.__test__ = False
-    __all__ += ['test']
