@@ -8,8 +8,8 @@ import tarfile
 import string
 import requests
 import warnings
+import importlib.resources as importlib_resources
 
-from pkg_resources import resource_filename
 from bs4 import BeautifulSoup
 import pyvo
 from urllib.parse import urljoin
@@ -19,13 +19,9 @@ from astroquery import log
 from astropy.utils.console import ProgressBar
 from astropy import units as u
 from astropy.time import Time
+from astropy.coordinates import SkyCoord
 
-try:
-    from pyvo.dal.sia2 import SIA2_PARAMETERS_DESC, SIA2Service
-except ImportError:
-    # Can be removed once min version of pyvo is 1.5
-    from pyvo.dal.sia2 import SIA_PARAMETERS_DESC as SIA2_PARAMETERS_DESC
-    from pyvo.dal.sia2 import SIAService as SIA2Service
+from pyvo.dal.sia2 import SIA2_PARAMETERS_DESC, SIA2Service
 
 from ..exceptions import LoginError
 from ..utils import commons
@@ -33,11 +29,11 @@ from ..utils.process_asyncs import async_to_sync
 from ..query import BaseQuery, QueryWithLogin, BaseVOQuery
 from .tapsql import (_gen_pos_sql, _gen_str_sql, _gen_numeric_sql,
                      _gen_band_list_sql, _gen_datetime_sql, _gen_pol_sql, _gen_pub_sql,
-                     _gen_science_sql, _gen_spec_res_sql, ALMA_DATE_FORMAT)
+                     _gen_science_sql, ALMA_DATE_FORMAT)
 from . import conf, auth_urls
 from astroquery.exceptions import CorruptDataWarning
 
-__all__ = {'AlmaClass', 'ALMA_BANDS'}
+__all__ = {'AlmaClass', 'ALMA_BANDS', 'get_enhanced_table'}
 
 __doctest_skip__ = ['AlmaClass.*']
 
@@ -55,7 +51,8 @@ _OBSCORE_TO_ALMARESULT = {
     'gal_latitude': 'Galactic latitude',
     'band_list': 'Band',
     's_region': 'Footprint',
-    'em_resolution': 'Frequency resolution',
+    'em_resolution': 'Frequency resolution (m)',
+    'spectral_resolution': 'Frequency resolution (Hz)',
     'antenna_arrays': 'Array',
     'is_mosaic': 'Mosaic',
     't_exptime': 'Integration',
@@ -115,7 +112,9 @@ ALMA_FORM_KEYS = {
         'Frequency (GHz)': ['frequency', 'frequency', _gen_numeric_sql],
         'Bandwidth (Hz)': ['bandwidth', 'bandwidth', _gen_numeric_sql],
         'Spectral resolution (KHz)': ['spectral_resolution',
-                                      'em_resolution', _gen_spec_res_sql],
+                                      'spectral_resolution', _gen_numeric_sql],
+        'Spectral resolution (m)': ['em_resolution',
+                                    'em_resolution', _gen_numeric_sql],
         'Band': ['band_list', 'band_list', _gen_band_list_sql]
     },
     'Time': {
@@ -139,7 +138,7 @@ ALMA_FORM_KEYS = {
     'Project': {
         'Project code': ['project_code', 'proposal_id', _gen_str_sql],
         'Project title': ['project_title', 'obs_title', _gen_str_sql],
-        'PI name': ['pi_name', 'obs_creator_name', _gen_str_sql],
+        'PI name': ['pi_name', 'pi_name', _gen_str_sql],
         'Proposal authors': ['proposal_authors', 'proposal_authors', _gen_str_sql],
         'Project abstract': ['project_abstract', 'proposal_abstract', _gen_str_sql],
         'Publication count': ['publication_count', 'NA', _gen_str_sql],
@@ -186,11 +185,7 @@ def _gen_sql(payload):
                         # use the value and the second entry in attrib which
                         # is the new name of the column
                         val = payload[constraint]
-                        if constraint == 'em_resolution':
-                            # em_resolution does not require any transformation
-                            attrib_where = _gen_numeric_sql(constraint, val)
-                        else:
-                            attrib_where = attrib[2](attrib[1], val)
+                        attrib_where = attrib[2](attrib[1], val)
                         if attrib_where:
                             if where:
                                 where += ' AND '
@@ -212,6 +207,107 @@ def _gen_sql(payload):
     return sql + where
 
 
+def get_enhanced_table(result):
+    """
+    Returns an enhanced table with quantities instead of values and regions for footprints.
+    Note that this function is dependent on the ``astropy`` - affiliated ``regions`` package.
+    """
+    try:
+        import regions
+    except ImportError:
+        print(
+            "Could not import astropy-regions, which is a requirement for get_enhanced_table function in alma."
+            "Please refer to https://astropy-regions.readthedocs.io/en/latest/installation.html for how to install it.")
+        raise
+
+    def _parse_stcs_string(input):
+        csys = 'icrs'
+
+        def _get_region(tokens):
+            if tokens[0] == 'polygon':
+                if csys == tokens[1].lower():
+                    tokens = tokens[2:]
+                else:
+                    tokens = tokens[1:]
+                points = SkyCoord(
+                    [(float(tokens[ii]), float(tokens[ii + 1])) * u.deg
+                     for ii in range(0, len(tokens), 2)], frame=csys)
+                return regions.PolygonSkyRegion(points)
+            elif tokens[0] == 'circle':
+                if csys == tokens[1].lower():
+                    tokens = tokens[2:]
+                else:
+                    tokens = tokens[1:]
+                return regions.CircleSkyRegion(
+                    SkyCoord(float(tokens[0]), float(tokens[1]), unit=u.deg),
+                    float(tokens[2]) * u.deg)
+            else:
+                raise ValueError("Unrecognized shape: " + tokens[0])
+        s_region = input.lower().strip()
+        if s_region.startswith('union'):
+            res = None
+            # skip the union operator
+            input_regions = s_region[s_region.index('(') + 1:s_region.rindex(
+                ')')].strip()
+            # omit the first char in the string to force it look for the second
+            # occurrence
+            last_pos = None
+            not_operation = False  # not operation - signals that the next substring is just the not operation
+            not_shape = False  # not shape - signals that the next substring is a not shape
+            for shape in re.finditer(r'not|polygon|circle', input_regions):
+                pos = shape.span()[0]
+                if last_pos is None:
+                    last_pos = pos
+                    continue  # this is the first elem
+                if shape.group() == 'not':
+                    not_operation = True
+                elif not_operation:
+                    not_shape = True
+                    not_operation = False
+                    last_pos = pos
+                    continue
+                if res is not None:
+                    next_shape = _get_region(
+                        input_regions[last_pos:pos - 1].strip(' ()').split())
+                    if not_shape:
+                        res = (res or next_shape) ^ next_shape
+                        not_shape = False
+                    else:
+                        res = res | next_shape
+                else:
+                    res = _get_region(
+                        input_regions[last_pos:pos - 1].strip().split())
+                last_pos = pos
+            if last_pos:
+                next_shape = _get_region(
+                    input_regions[last_pos:].strip(' ()').split())
+                res = res | next_shape
+            return res
+        elif 'not' in s_region:
+            # shape with "holes"
+            comps = s_region.split('not')
+            result = _get_region(comps[0].strip(' ()').split())
+            for comp in comps[1:]:
+                hole = _get_region(comp.strip(' ()').split())
+                result = (result or hole) ^ hole
+            return result
+        else:
+            return _get_region(s_region.split())
+    prep_table = result.to_qtable()
+    s_region_parser = None
+    for field in result.resultstable.fields:
+        if ('s_region' == field.ID) and \
+                ('obscore:Char.SpatialAxis.Coverage.Support.Area' == field.utype):
+            if 'adql:REGION' == field.xtype:
+                s_region_parser = _parse_stcs_string
+            # this is where to add other xtype parsers such as shape
+            break
+    if (s_region_parser):
+        for row in prep_table:
+            row['s_region'] = s_region_parser(row['s_region'])
+    return prep_table
+
+
 class AlmaAuth(BaseVOQuery, BaseQuery):
     """Authentication session information for passing credentials to an OIDC instance
 
@@ -381,7 +477,8 @@ class AlmaClass(QueryWithLogin):
         return self._tap_url
 
     def query_object_async(self, object_name, *, public=True,
-                           science=True, payload=None, **kwargs):
+                           science=True, payload=None, enhanced_results=False,
+                           **kwargs):
         """
         Query the archive for a source name.
 
@@ -395,6 +492,9 @@ class AlmaClass(QueryWithLogin):
         science : bool
             True to return only science datasets, False to return only
             calibration, None to return both
+        enhanced_results : bool
+            True to return a table with quantities instead of just values. It
+            also returns the footprint as `regions` objects.
         payload : dict
             Dictionary of additional keywords.  See `help`.
         """
@@ -403,10 +503,12 @@ class AlmaClass(QueryWithLogin):
         else:
             payload = {'source_name_resolver': object_name}
         return self.query_async(public=public, science=science,
-                                payload=payload, **kwargs)
+                                payload=payload, enhanced_results=enhanced_results,
+                                **kwargs)
 
     def query_region_async(self, coordinate, radius, *, public=True,
-                           science=True, payload=None, **kwargs):
+                           science=True, payload=None, enhanced_results=False,
+                           **kwargs):
         """
         Query the ALMA archive with a source name and radius
 
@@ -424,6 +526,9 @@ class AlmaClass(QueryWithLogin):
             calibration, None to return both
         payload : dict
             Dictionary of additional keywords.  See `help`.
+        enhanced_results : bool
+            True to return a table with quantities instead of just values. It
+            also returns the footprints as `regions` objects.
         """
         rad = radius
         if not isinstance(radius, u.Quantity):
@@ -438,11 +543,12 @@ class AlmaClass(QueryWithLogin):
             payload['ra_dec'] = ra_dec
 
         return self.query_async(public=public, science=science,
-                                payload=payload, **kwargs)
+                                payload=payload, enhanced_results=enhanced_results,
+                                **kwargs)
 
     def query_async(self, payload, *, public=True, science=True,
                     legacy_columns=False, get_query_payload=False,
-                    maxrec=None, **kwargs):
+                    maxrec=None, enhanced_results=False, **kwargs):
         """
         Perform a generic query with user-specified payload
 
@@ -463,6 +569,9 @@ class AlmaClass(QueryWithLogin):
             Flag to indicate whether to simply return the payload.
         maxrec : integer
             Cap on the amount of records returned.  Default is no limit.
+        enhanced_results : bool
+            True to return a table with quantities instead of just values. It
+            also returns the footprints as `regions` objects.
 
         Returns
         -------
@@ -485,6 +594,11 @@ class AlmaClass(QueryWithLogin):
         if science is not None:
             payload['science_observation'] = science
         if public is not None:
+            if 'public_data' in kwargs:
+                warnings.warn("Both public and public_data are set. "
+                              "The ``public`` kwarg takes precedence. "
+                              "If you want ``public_data`` to be respected, "
+                              "set ``public=None``.")
             payload['public_data'] = public
 
         query = _gen_sql(payload)
@@ -497,7 +611,10 @@ class AlmaClass(QueryWithLogin):
         result = self.query_tap(query, maxrec=maxrec)
 
         if result is not None:
-            result = result.to_table()
+            if enhanced_results:
+                result = get_enhanced_table(result)
+            else:
+                result = result.to_table()
         else:
             # Should not happen
             raise RuntimeError('BUG: Unexpected result None')
@@ -540,8 +657,8 @@ class AlmaClass(QueryWithLogin):
 
         Returns
         -------
-        Results in ``pyvo.dal.sia2.SIA2Results`` format.
-        result.table in Astropy table format
+        Results in `~pyvo.dal.sia2.SIA2Results` format.
+        result.to_qtable in `~astropy.table.QTable` format
         """
         return self.sia.search(
             pos=pos,
@@ -564,25 +681,40 @@ class AlmaClass(QueryWithLogin):
             maxrec=maxrec,
             **kwargs)
 
-    # SIA2_PARAMETERS_DESC contains links that Sphinx can't resolve.
-    for var in ('POLARIZATION_STATES', 'CALIBRATION_LEVELS'):
-        SIA2_PARAMETERS_DESC = SIA2_PARAMETERS_DESC.replace(f'`pyvo.dam.obscore.{var}`',
-                                                            f'pyvo.dam.obscore.{var}')
     query_sia.__doc__ = query_sia.__doc__.replace('_SIA2_PARAMETERS', SIA2_PARAMETERS_DESC)
 
-    def query_tap(self, query, maxrec=None):
+    def query_tap(self, query, *, maxrec=None, uploads=None):
         """
-        Send query to the ALMA TAP. Results in pyvo.dal.TapResult format.
-        result.table in Astropy table format
+        Send query to the ALMA TAP. Results in `~pyvo.dal.TAPResults` format.
+        result.to_qtable in `~astropy.table.QTable` format
 
         Parameters
         ----------
+        query : str
+            ADQL query to be executed
         maxrec : int
             maximum number of records to return
+        uploads : dict
+            a mapping from temporary table names to objects containing a votable. These
+            temporary tables can be referred to in queries. The keys in the dictionary are
+            the names of temporary tables which need to be prefixed with the TAP_UPLOAD
+            schema in the actual query. The values are either astropy.table.Table instances
+            or file names or file like handles such as io.StringIO to table definition in
+            IVOA VOTable format.
+
+    Examples
+    --------
+    >>> uploads = {'tmptable': '/tmp/tmptable_def.xml'}
+    >>> rslt = query_tap(self, query, maxrec=None, uploads=uploads)
+
+        Return
+        ------
+        result : `~pyvo.dal.TAPResults`
+            TAP query result
 
         """
         log.debug('TAP query: {}'.format(query))
-        return self.tap.search(query, language='ADQL', maxrec=maxrec)
+        return self.tap.search(query, language='ADQL', maxrec=maxrec, uploads=uploads)
 
     def help_tap(self):
         print('Table to query is "voa.ObsCore".')
@@ -1021,7 +1153,7 @@ class AlmaClass(QueryWithLogin):
         List the file contents of a UID from Cycle 0.  Will raise an error
         if the UID is from cycle 1+, since those data have been released in
         a different and more consistent format.  See
-        https://almascience.org/documents-and-tools/cycle-2/ALMAQA2Productsv1.01.pdf
+        https://almascience.nrao.edu/documents-and-tools/cycle-2/ALMAQA2Productsv1.01.pdf
         for details.
         """
 
@@ -1054,9 +1186,9 @@ class AlmaClass(QueryWithLogin):
             # <tr width="blah"> which the default parser does not pick up
             root = BeautifulSoup(response.content, 'html.parser')
             html_table = root.find('table', class_='grid listing')
-            data = list(zip(*[(x.findAll('td')[0].text,
-                               x.findAll('td')[1].text)
-                              for x in html_table.findAll('tr')]))
+            data = list(zip(*[(x.find_all('td')[0].text,
+                               x.find_all('td')[1].text)
+                              for x in html_table.find_all('tr')]))
             columns = [Column(data=data[0], name='ID'),
                        Column(data=data[1], name='Files')]
             tbl = Table(columns)
@@ -1075,10 +1207,9 @@ class AlmaClass(QueryWithLogin):
         Stoehr.
         """
         if not hasattr(self, '_cycle0_table'):
-            filename = resource_filename(
-                'astroquery.alma', 'data/cycle0_delivery_asdm_mapping.txt')
-
-            self._cycle0_table = Table.read(filename, format='ascii.no_header')
+            ref = importlib_resources.files('astroquery.alma') / 'data' / 'cycle0_delivery_asdm_mapping.txt'
+            with importlib_resources.as_file(ref) as path:
+                self._cycle0_table = Table.read(path, format='ascii.no_header')
             self._cycle0_table.rename_column('col1', 'ID')
             self._cycle0_table.rename_column('col2', 'uid')
         return self._cycle0_table
