@@ -1,6 +1,7 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 from datetime import datetime, timezone
 import os
+from io import StringIO
 from pathlib import Path
 from urllib.parse import urlparse
 import re
@@ -10,16 +11,19 @@ from astropy import coordinates
 from astropy import units as u
 import numpy as np
 import pytest
-try:
-    # This requires pyvo 1.4
-    from pyvo.dal.exceptions import DALOverflowWarning
-except ImportError:
-    pass
+
+from pyvo.dal.exceptions import DALOverflowWarning
 
 from astroquery.exceptions import CorruptDataWarning
-from .. import Alma
+from astroquery.alma import Alma, get_enhanced_table
+
+try:
+    import regions
+
+    HAS_REGIONS = True
+except ImportError:
+    HAS_REGIONS = False
 
-# ALMA tests involving staging take too long, leading to travis timeouts
 # TODO: make this a configuration item
 SKIP_SLOW = True
 
@@ -33,6 +37,9 @@ all_colnames = {'Project code', 'Source name', 'RA', 'Dec', 'Band',
 
 download_hostname = 'almascience.eso.org'
 
+# The MAXREC related overflow message is different in pyvo 1.7+, remove workaround when we have it as a minimum
+overflow_message = r"Partial result set. Potential causes MAXREC|Result set limited by user- or server-supplied MAXREC"
+
 
 @pytest.fixture
 def alma(request):
@@ -52,29 +59,40 @@ def alma(request):
 @pytest.mark.remote_data
 class TestAlma:
     def test_public(self, alma):
-        # This warning was added in pyvo 1.4, but we don't test older versions with remote-data
-        with pytest.warns(expected_warning=DALOverflowWarning,
-                          match="Partial result set. Potential causes MAXREC, async storage space, etc."):
+        with pytest.warns(expected_warning=DALOverflowWarning, match=overflow_message):
             results = alma.query(payload=None, public=True, maxrec=100)
         assert len(results) == 100
         for row in results:
             assert row['data_rights'] == 'Public'
-        with pytest.warns(expected_warning=DALOverflowWarning,
-                          match="Partial result set. Potential causes MAXREC, async storage space, etc."):
+        with pytest.warns(expected_warning=DALOverflowWarning, match=overflow_message):
             results = alma.query(payload=None, public=False, maxrec=100)
         assert len(results) == 100
         for row in results:
             assert row['data_rights'] == 'Proprietary'
 
+    @pytest.mark.skipif(not HAS_REGIONS, reason="regions is required")
+    @pytest.mark.filterwarnings(
+        "ignore::astropy.utils.exceptions.AstropyUserWarning")
+    def test_s_region(self, alma):
+        alma.help_tap()
+        result = alma.query_tap("select top 3 s_region from ivoa.obscore")
+        enhanced_result = get_enhanced_table(result)
+        for row in enhanced_result:
+            assert isinstance(row['s_region'], (regions.CircleSkyRegion,
+                                                regions.PolygonSkyRegion,
+                                                regions.CompoundSkyRegion))
+
+    @pytest.mark.skipif(not HAS_REGIONS, reason="regions is required")
+    @pytest.mark.filterwarnings(
+        "ignore::astropy.utils.exceptions.AstropyUserWarning")
     def test_SgrAstar(self, tmp_path, alma):
         alma.cache_location = tmp_path
 
-        result_s = alma.query_object('Sgr A*', legacy_columns=True)
+        result_s = alma.query_object('Sgr A*', legacy_columns=True, enhanced_results=True)
 
         assert '2013.1.00857.S' in result_s['Project code']
-        # "The Brick", g0.253, is in this one
-        # assert b'2011.0.00217.S' in result_c['Project code'] # missing cycle 1 data
 
+    @pytest.mark.skipif("SKIP_SLOW")
     def test_freq(self, alma):
         payload = {'frequency': '85..86'}
         result = alma.query(payload)
@@ -82,15 +100,13 @@ class TestAlma:
         for row in result:
             # returned em_min and em_max are in m
             assert row['frequency'] >= 85
-            assert row['frequency'] <= 100
+            assert row['frequency'] <= 86
             assert '3' in row['band_list']
 
     def test_bands(self, alma):
         payload = {'band_list': ['5', '7']}
         # Added maxrec here as downloading and reading the results take too long.
-        # This warning was added in pyvo 1.4, but we don't test older versions with remote-data
-        with pytest.warns(expected_warning=DALOverflowWarning,
-                          match="Partial result set. Potential causes MAXREC, async storage space, etc."):
+        with pytest.warns(expected_warning=DALOverflowWarning, match=overflow_message):
             result = alma.query(payload, maxrec=1000)
         assert len(result) > 0
         for row in result:
@@ -150,6 +166,7 @@ class TestAlma:
         with pytest.raises(AttributeError):
             alma.is_proprietary('uid://NON/EXI/STING')
 
+    @pytest.mark.bigdata
     def test_retrieve_data(self, tmp_path, alma):
         """
         Regression test for issue 2490 (the retrieval step will simply fail if
@@ -200,10 +217,7 @@ class TestAlma:
         trimmed_access_url_list = [e for e in data_info_tar['access_url'].data if len(e) > 0]
         trimmed_access_urls = (trimmed_access_url_list,)
         mock_calls = download_files_mock.mock_calls[0][1]
-        print(f"\n\nComparing {mock_calls} to {trimmed_access_urls}\n\n")
-        # comparison = download_files_mock.mock_calls[0][1] == data_info_tar['access_url']
         assert mock_calls == trimmed_access_urls
-        # assert comparison.all()
 
     def test_download_data(self, tmp_path, alma):
         # test only fits files from a program
@@ -223,9 +237,8 @@ class TestAlma:
         alma._download_file.call_count == len(results)
         assert len(results) == len(urls)
 
+    @pytest.mark.skipif("SKIP_SLOW")
     def test_download_and_extract(self, tmp_path, alma):
-        # TODO: slowish, runs for ~90s
-
         alma.cache_location = tmp_path
         alma._cycle0_tarfile_content_table = {'ID': ''}
 
@@ -329,16 +342,17 @@ class TestAlma:
 
         result = alma.query_object('M83', public=True, science=True)
         assert len(result) > 0
-        result = alma.query(payload={'pi_name': '*Bally*'}, public=False,
-                            maxrec=10)
+        with pytest.warns(expected_warning=DALOverflowWarning, match=overflow_message):
+            result = alma.query(payload={'pi_name': 'Bally*'}, public=True,
+                                maxrec=10)
         assert result
         # Add overwrite=True in case the test previously died unexpectedly
         # and left the temp file.
         result.write('/tmp/alma-onerow.txt', format='ascii', overwrite=True)
         for row in result:
-            assert 'Bally' in row['obs_creator_name']
+            assert 'Bally' in row['pi_name']
         result = alma.query(payload=dict(project_code='2016.1.00165.S'),
-                            public=False)
+                            public=True)
         assert result
         for row in result:
             assert '2016.1.00165.S' == row['proposal_id']
@@ -382,8 +396,9 @@ class TestAlma:
         assert result
         for row in result:
             assert '6' == row['band_list']
-            assert 'ginsburg' in row['obs_creator_name'].lower()
+            assert 'ginsburg' in row['pi_name'].lower()
 
+    @pytest.mark.skip("Not sure what this is supposed to do")
     def test_user(self, alma):
         # miscellaneous set of tests from current users
         rslt = alma.query({'band_list': [6], 'project_code': '2012.1.*'},
@@ -545,6 +560,36 @@ def test_big_download_regression(alma):
     alma.download_files([files['access_url'][3]])
 
 
+@pytest.mark.remote_data
+def test_tap_upload():
+    tmp_table = StringIO('''<?xml version="1.0" encoding="UTF-8"?>
+    <VOTABLE xmlns="http://www.ivoa.net/xml/VOTable/v1.3"
+    xmlns:xsi="http://www.w3.org/2001/XMLSchema-instance" version="1.3">
+      <RESOURCE>
+        <TABLE>
+          <FIELD name="prop_id" datatype="char" arraysize="*">
+            <DESCRIPTION>external URI for the physical artifact</DESCRIPTION>
+          </FIELD>
+          <DATA>
+            <TABLEDATA>
+              <TR>
+                <TD>2013.1.01365.S</TD>
+              </TR>
+            </TABLEDATA>
+          </DATA>
+        </TABLE>
+      </RESOURCE>
+    </VOTABLE>''')
+
+    alma = Alma()
+    res = alma.query_tap(
+        'select top 3 proposal_id from ivoa.ObsCore oc join TAP_UPLOAD.proj_codes pc on oc.proposal_id=pc.prop_id',
+        uploads={'proj_codes': tmp_table})
+    assert len(res) == 3
+    for row in res:
+        assert row['proposal_id'] == '2013.1.01365.S'
+
+
 @pytest.mark.remote_data
 def test_download_html_file(alma, tmp_path):
     alma.cache_location = tmp_path
