@@ -2,10 +2,12 @@
 
 
 import json
+import warnings
 
 from astropy.io import fits
 from astropy.stats import sigma_clipped_stats
 from astropy.coordinates import SkyCoord
+from astropy.utils.decorators import AstropyDeprecationWarning, deprecated_renamed_argument
 
 try:
     from astropy.nddata import CCDData
@@ -244,11 +246,12 @@ class AstrometryNetClass(BaseQuery):
         status = ''
         while not has_completed:
             time.sleep(1)
-            sub_stat_url = url_helpers.join(self.API_URL, 'submissions', str(submission_id))
-            sub_stat = self._request('GET', sub_stat_url, cache=False)
-            jobs = sub_stat.json()['jobs']
-            if jobs:
-                job_id = jobs[0]
+            if job_id is None:
+                sub_stat_url = url_helpers.join(self.API_URL, 'submissions', str(submission_id))
+                sub_stat = self._request('GET', sub_stat_url, cache=False)
+                jobs = sub_stat.json()['jobs']
+                if jobs:
+                    job_id = jobs[0]
             if job_id:
                 job_stat_url = url_helpers.join(self.API_URL, 'jobs',
                                                 str(job_id), 'info')
@@ -331,6 +334,7 @@ class AstrometryNetClass(BaseQuery):
                                        verbose=verbose,
                                        return_submission_id=return_submission_id)
 
+    @deprecated_renamed_argument(("force_image_upload", "ra_dec_units"), (None, None), since="0.4.8")
     def solve_from_image(self, image_file_path, *, force_image_upload=False,
                          ra_key=None, dec_key=None,
                          ra_dec_units=None,
@@ -342,7 +346,7 @@ class AstrometryNetClass(BaseQuery):
         """
         Plate solve from an image, either by uploading the image to
         astrometry.net or by finding sources locally using
-        `photutils <https://photutils.rtfd.io>`_ and solving with source
+        `photutils <https://photutils.readthedocs.io/en/stable/>`_ and solving with source
         locations.
 
         Parameters
@@ -412,6 +416,14 @@ class AstrometryNetClass(BaseQuery):
                                          cache=False,
                                          files={'file': f})
         else:
+            warning_msg = (
+                "Removing photutils functionality to obtain extracted positions list from "
+                "AstrometryNetClass.solve_from_source_list. Users will need to "
+                "submit pre-extracted catalog positions or a fits file for https://nova.astrometry.net/ "
+                "to extract with their algorithm."
+            )
+
+            warnings.warn(warning_msg, category=AstropyDeprecationWarning)
             # Detect sources and delegate to solve_from_source_list
             if _HAVE_CCDDATA:
                 # CCDData requires a unit, so provide one. It has absolutely
