@@ -11,5 +11,5 @@ def is_valid_transitions_param(transitions):
     is_custom_choice = isinstance(transitions, MultiTransition) and\
         all(t not in simple_transitions for t in transitions)
 
-    return (transitions is None or transitions in simple_transitions or
-            is_custom_choice)
+    return (transitions is None or transitions in simple_transitions
+            or is_custom_choice)
