@@ -1,11 +1,10 @@
 # Licensed under a 3-clause BSD style license - see LICENSE.rst
 """
-
-@author: Javier Duran
-@contact: javier.duran@sciops.esa.int
+==========
+eHST Init
+==========
 
 European Space Astronomy Centre (ESAC)
 European Space Agency (ESA)
 
-Created on 13 Aug. 2018
 """
