@@ -6,7 +6,7 @@ LAMDA Query Tool
 :Author: Brian Svoboda (svobodb@email.arizona.edu)
 
 This package is for querying the Leiden Atomic and Molecular Database (LAMDA)
-hosted at: http://home.strw.leidenuniv.nl/~moldata/.
+hosted at: https://home.strw.leidenuniv.nl/~moldata/.
 
 Note:
   If you use the data files from LAMDA in your research work please refer to
