@@ -6,6 +6,7 @@ Discovery Portal API
 This module contains various methods for querying the MAST Discovery Portal API.
 """
 
+import difflib
 import warnings
 import uuid
 import json
@@ -20,7 +21,7 @@ from astropy.table import Table, vstack, MaskedColumn
 from ..query import BaseQuery
 from ..utils import async_to_sync
 from ..utils.class_or_instance import class_or_instance
-from ..exceptions import InputWarning, NoResultsWarning, RemoteServiceError
+from ..exceptions import InputWarning, InvalidQueryError, NoResultsWarning, RemoteServiceError
 
 from . import conf, utils
 
@@ -100,8 +101,9 @@ def _json_to_table(json_obj, col_config=None):
         else:
             col_mask = np.equal(col_data, ignore_value)
 
-        # add the column
-        data_table.add_column(MaskedColumn(col_data.astype(atype), name=col, mask=col_mask))
+        # add the column if it does not exist already
+        if col not in data_table.colnames:
+            data_table.add_column(MaskedColumn(col_data.astype(atype), name=col, mask=col_mask))
 
     return data_table
 
@@ -403,11 +405,13 @@ class PortalAPI(BaseQuery):
             if np.isscalar(value,):
                 value = [value]
 
-            # Get the column type and separator
-            col_info = caom_col_config.get(colname)
+            # Get the column type and separator with case-insensitive lookup
+            col_info = next((v for k, v in caom_col_config.items() if k.lower() == colname.lower()), None)
             if not col_info:
-                warnings.warn("Filter {} does not exist. This filter will be skipped.".format(colname), InputWarning)
-                continue
+                closest_match = difflib.get_close_matches(colname, caom_col_config.keys(), n=1)
+                error_msg = f"Filter '{colname}' does not exist. Did you mean '{closest_match[0]}'?" if closest_match \
+                    else f"Filter '{colname}' does not exist."
+                raise InvalidQueryError(error_msg)
 
             colType = "discrete"
             if (col_info.get("vot.datatype", col_info.get("type")) in ("double", "float", "numeric")) \
