@@ -12,11 +12,13 @@ import warnings
 import numpy as np
 
 from astropy.table import Table, MaskedColumn
+from astropy.utils.decorators import deprecated_renamed_argument
 
+from .. import log
 from ..query import BaseQuery
 from ..utils import async_to_sync
 from ..utils.class_or_instance import class_or_instance
-from ..exceptions import TimeoutError, NoResultsWarning
+from ..exceptions import InvalidQueryError, TimeoutError, NoResultsWarning
 
 from . import conf
 
@@ -51,14 +53,18 @@ def _json_to_table(json_obj, data_key='data'):
     # for each item in info, type has to be converted from DB data types (SQL server in most cases)
     # from missions_mast search service such as varchar, integer, float, boolean etc
     # to corresponding numpy type
-    for idx, col, col_type, ignore_value in \
-            [(idx, x['name'], x[type_key].lower(), None) for idx, x in enumerate(json_obj['info'])]:
+    for idx, col in enumerate(json_obj['info']):
+
+        # get column name and type
+        col_name = col.get('column_name') or col.get('name')
+        col_type = col[type_key].lower()
+        ignore_value = None
 
         # making type adjustments
         if (col_type == "char" or col_type == "string" or 'varchar' in col_type or col_type == "null"
                 or col_type == 'datetime'):
             col_type = "str"
-            ignore_value = "" if (ignore_value is None) else ignore_value
+            ignore_value = ""
         elif col_type == "boolean" or col_type == "binary":
             col_type = "bool"
         elif col_type == "unsignedbyte":
@@ -67,11 +73,11 @@ def _json_to_table(json_obj, data_key='data'):
                 or col_type == 'integer'):
             # int arrays do not admit Non/nan vals
             col_type = np.int64
-            ignore_value = -999 if (ignore_value is None) else ignore_value
+            ignore_value = -999
         elif col_type == "double" or col_type.lower() == "float" or col_type == "decimal":
             # int arrays do not admit Non/nan vals
             col_type = np.float64
-            ignore_value = -999 if (ignore_value is None) else ignore_value
+            ignore_value = -999
 
         # Make the column list (don't assign final type yet or there will be errors)
         try:
@@ -79,7 +85,12 @@ def _json_to_table(json_obj, data_key='data'):
             col_data = np.array([x[idx] for x in json_obj[data_key]], dtype=object)
         except KeyError:
             # it's not a data array, fall back to using column name as it is array of dictionaries
-            col_data = np.array([x[col] for x in json_obj[data_key]], dtype=object)
+            try:
+                col_data = np.array([x[col_name] for x in json_obj[data_key]], dtype=object)
+            except KeyError:
+                # Skip column names not found in data
+                log.debug('Column %s was not found in data. Skipping...', col_name)
+                continue
         if ignore_value is not None:
             col_data[np.where(np.equal(col_data, None))] = ignore_value
 
@@ -90,8 +101,9 @@ def _json_to_table(json_obj, data_key='data'):
         else:
             col_mask = np.equal(col_data, ignore_value)
 
-        # add the column
-        data_table.add_column(MaskedColumn(col_data.astype(col_type), name=col, mask=col_mask))
+        # add the column if it does not exist already
+        if col_name not in data_table.colnames:
+            data_table.add_column(MaskedColumn(col_data.astype(col_type), name=col_name, mask=col_mask))
 
     return data_table
 
@@ -107,6 +119,8 @@ class ServiceAPI(BaseQuery):
 
     SERVICE_URL = conf.server
     REQUEST_URL = conf.server + "/api/v0.1/"
+    MISSIONS_DOWNLOAD_URL = conf.server + "/search/"
+    MAST_DOWNLOAD_URL = conf.server + "/api/v0.1/Download/file"
     SERVICES = {}
 
     def __init__(self, session=None):
@@ -190,6 +204,12 @@ class ServiceAPI(BaseQuery):
         if (time.time() - start_time) >= self.TIMEOUT:
             raise TimeoutError("Timeout limit of {} exceeded.".format(self.TIMEOUT))
 
+        if response.status_code in [400, 500]:
+            raise InvalidQueryError('The server was unable to process the request due to invalid input. '
+                                    'Please check the query parameters and try again. Use the '
+                                    '`MastMissions.get_column_list` method to see the available searchable '
+                                    'columns and their expected data types.')
+
         response.raise_for_status()
         return response
 
@@ -222,7 +242,8 @@ class ServiceAPI(BaseQuery):
         return result_table
 
     @class_or_instance
-    def service_request_async(self, service, params, page_size=None, page=None, use_json=False, **kwargs):
+    @deprecated_renamed_argument('page_size', 'pagesize', since='0.4.8')
+    def service_request_async(self, service, params, pagesize=None, page=None, use_json=False, **kwargs):
         """
         Given a MAST fabric service and parameters, builds and executes a fabric microservice catalog query.
         See documentation `here <https://catalogs.mast.stsci.edu/docs/index.html>`__
@@ -234,7 +255,7 @@ class ServiceAPI(BaseQuery):
            The MAST catalogs service to query. Should be present in self.SERVICES
         params : dict
            JSON object containing service parameters.
-        page_size : int, optional
+        pagesize : int, optional
            Default None.
            Can be used to override the default pagesize (set in configs) for this query only.
            E.g. when using a slow internet connection.
@@ -264,27 +285,28 @@ class ServiceAPI(BaseQuery):
 
         request_url = self.REQUEST_URL + service_url.format(**compiled_service_args)
 
+        # Default headers
         headers = {
             'User-Agent': self._session.headers['User-Agent'],
             'Content-Type': 'application/x-www-form-urlencoded',
             'Accept': 'application/json'
         }
+
         # Params as a list of tuples to allow for multiple parameters added
         catalogs_request = []
-        if not page:
-            page = params.pop('page', None)
-        if not page_size:
-            page_size = params.pop('page_size', None)
+        page = page or params.pop('page', None)
+        pagesize = pagesize or params.pop('pagesize', None)
 
+        # Add pagination if specified
         if page is not None:
             catalogs_request.append(('page', page))
-        if page_size is not None:
-            catalogs_request.append(('pagesize', page_size))
+        if pagesize is not None:
+            catalogs_request.append(('pagesize', pagesize))
 
+        # Populate parameters based on `use_json`
         if not use_json:
-            # Decompose filters, sort
-            for prop, value in kwargs.items():
-                params[prop] = value
+            # When not using JSON, merge kwargs into params and build query
+            params.update(kwargs)
             catalogs_request.extend(self._build_catalogs_params(params))
         else:
             headers['Content-Type'] = 'application/json'
@@ -301,9 +323,10 @@ class ServiceAPI(BaseQuery):
                 catalogs_request = params_dict
 
                 # Removing single-element lists. Single values will live on their own (except for `sort_by`)
-                for key in catalogs_request.keys():
-                    if (key != 'sort_by') & (len(catalogs_request[key]) == 1):
-                        catalogs_request[key] = catalogs_request[key][0]
+                catalogs_request = {
+                    k: v if k == 'sort_by' or len(v) > 1 else v[0]
+                    for k, v in params_dict.items()
+                }
 
             # Otherwise, catalogs_request can remain as the original params dict
             else:
@@ -312,6 +335,40 @@ class ServiceAPI(BaseQuery):
         response = self._request('POST', request_url, data=catalogs_request, headers=headers, use_json=use_json)
         return response
 
+    @class_or_instance
+    def missions_request_async(self, service, params):
+        """
+        Builds and executes an asynchronous query to the MAST Search API.
+        Parameters
+        ----------
+        service : str
+           The MAST Search API service to query. Should be present in self.SERVICES.
+        params : dict
+           JSON object containing service parameters.
+        Returns
+        -------
+        response : list of `~requests.Response`
+        """
+        service_config = self.SERVICES.get(service.lower())
+        request_url = self.REQUEST_URL + service_config.get('path')
+
+        # Default headers
+        headers = {
+            'User-Agent': self._session.headers['User-Agent'],
+            'Content-Type': 'application/json',
+            'Accept': 'application/json'
+        }
+
+        # make request
+        data, params = (params, None)
+        response = self._request(method='POST',
+                                 url=request_url,
+                                 params=params,
+                                 data=data,
+                                 headers=headers,
+                                 use_json=True)
+        return response
+
     def _build_catalogs_params(self, params):
         """
         Gathers parameters for Catalogs.MAST usage and translates to valid API syntax tuples
@@ -331,7 +388,7 @@ class ServiceAPI(BaseQuery):
             if prop == 'format':
                 # Ignore format changes
                 continue
-            elif prop == 'page_size':
+            elif prop == 'pagesize':
                 catalog_params.extend(('pagesize', value))
             elif prop == 'sort_by':
                 # Loop through each value if list
@@ -381,12 +438,6 @@ class ServiceAPI(BaseQuery):
         response : boolean
             Whether the passed dict has at least one criteria parameter
         """
-        criteria_check = False
-        non_criteria_params = ["columns", "sort_by", "page_size", "pagesize", "page"]
-        criteria_keys = criteria.keys()
-        for key in criteria_keys:
-            if key not in non_criteria_params:
-                criteria_check = True
-                break
 
-        return criteria_check
+        non_criteria_params = ["columns", "sort_by", "page_size", "pagesize", "page"]
+        return any(key not in non_criteria_params for key in criteria)
