@@ -1,6 +1,6 @@
 
 
-def _get_data_from_xml(doclist, fieldname, nohitreturn=None):
+def _get_data_from_xml(doclist, fieldname, *, nohitreturn=None):
     """Get the fieldname (i.e. author, title etc)
     from minidom.parseString().childNodes[0].childNodes list
     """
