@@ -6,8 +6,8 @@ from astropy.table import Table
 from astropy.utils.data import get_pkg_data_contents
 from astropy.utils.exceptions import AstropyUserWarning
 
-from . import conf
-from ..utils.mocks import MockResponse
+from astroquery.sdss import conf
+from astroquery.utils.mocks import MockResponse
 
 __all__ = ['get_field_info', 'photoobj_defs', 'specobj_defs', 'crossid_defs']
 
