@@ -79,17 +79,18 @@ class SkyViewClass(BaseQuery):
         url = urlparse.urljoin(self.URL, form.get('action'))
         return url, payload
 
-    def _submit_form(self, input=None, cache=True):
+    def _submit_form(self, input=None, cache=True, get_query_payload=False):
         url, payload = self._generate_payload(input=input)
+        if get_query_payload:
+            return payload
         response = self._request('GET', url, params=payload, cache=cache)
         response.raise_for_status()
         return response
 
     def get_images(self, position, survey, *, coordinates=None, projection=None,
                    pixels=None, scaling=None, sampler=None, resolver=None,
-                   deedger=None, lut=None, grid=None, gridlabels=None,
-                   radius=None, height=None, width=None, cache=True,
-                   show_progress=True):
+                   deedger=None, radius=None, height=None, width=None, cache=True,
+                   show_progress=True, get_query_payload=False):
         """
         Query the SkyView service, download the FITS file that will be
         found and return a generator over the local paths to the
@@ -164,13 +165,6 @@ class SkyViewClass(BaseQuery):
             de-edging algorithm. The supported values are: ``"_skip_"`` to
             use the survey default, ``"skyview.process.Deedger"`` (for
             enabling de-edging), and ``"null"`` to disable.
-        lut : str
-            Choose from the color table selections to display the data in
-            false color.
-        grid : bool
-            overlay a coordinate grid on the image if True
-        gridlabels : bool
-            annotate the grid with coordinates positions if True
         radius : `~astropy.units.Quantity` or None
             The angular radius of the specified field.
             Overrides the ``width`` and ``height`` parameters.
@@ -186,7 +180,7 @@ class SkyViewClass(BaseQuery):
 
         References
         ----------
-        .. [1] http://skyview.gsfc.nasa.gov/current/help/fields.html
+        .. [1] https://skyview.gsfc.nasa.gov/current/help/fields.html
 
         Examples
         --------
@@ -204,17 +198,19 @@ class SkyViewClass(BaseQuery):
         readable_objects = self.get_images_async(position, survey, coordinates=coordinates,
                                                  projection=projection, pixels=pixels, scaling=scaling,
                                                  sampler=sampler, resolver=resolver, deedger=deedger,
-                                                 lut=lut, grid=grid, gridlabels=gridlabels,
                                                  radius=radius, height=height, width=width,
-                                                 cache=cache, show_progress=show_progress)
+                                                 cache=cache, show_progress=show_progress,
+                                                 get_query_payload=get_query_payload)
+        if get_query_payload:
+            return readable_objects
         return [obj.get_fits() for obj in readable_objects]
 
     @prepend_docstr_nosections(get_images.__doc__)
     def get_images_async(self, position, survey, *, coordinates=None,
                          projection=None, pixels=None, scaling=None,
-                         sampler=None, resolver=None, deedger=None, lut=None,
-                         grid=None, gridlabels=None, radius=None, height=None,
-                         width=None, cache=True, show_progress=True):
+                         sampler=None, resolver=None, deedger=None,
+                         radius=None, height=None, width=None,
+                         cache=True, show_progress=True, get_query_payload=False):
         """
         Returns
         -------
@@ -222,20 +218,20 @@ class SkyViewClass(BaseQuery):
         """
         image_urls = self.get_image_list(position, survey, coordinates=coordinates,
                                          projection=projection, pixels=pixels, scaling=scaling, sampler=sampler,
-                                         resolver=resolver, deedger=deedger, lut=lut, grid=grid,
-                                         gridlabels=gridlabels, radius=radius,
-                                         height=height, width=width,
-                                         cache=cache)
-        return [commons.FileContainer(url, encoding='binary',
-                                      show_progress=show_progress)
+                                         resolver=resolver, deedger=deedger, radius=radius,
+                                         height=height, width=width, cache=cache,
+                                         get_query_payload=get_query_payload)
+        if get_query_payload:
+            return image_urls
+        return [commons.FileContainer(url, encoding='binary', show_progress=show_progress)
                 for url in image_urls]
 
     @prepend_docstr_nosections(get_images.__doc__, sections=['Returns', 'Examples'])
     def get_image_list(self, position, survey, *, coordinates=None,
                        projection=None, pixels=None, scaling=None,
-                       sampler=None, resolver=None, deedger=None, lut=None,
-                       grid=None, gridlabels=None, radius=None, width=None,
-                       height=None, cache=True):
+                       sampler=None, resolver=None, deedger=None,
+                       radius=None, width=None, height=None, cache=True,
+                       get_query_payload=False):
         """
         Returns
         -------
@@ -267,18 +263,17 @@ class SkyViewClass(BaseQuery):
             'Position': parse_coordinates(position),
             'survey': survey,
             'Deedger': deedger,
-            'lut': lut,
             'projection': projection,
-            'gridlabels': '1' if gridlabels else '0',
             'coordinates': coordinates,
             'scaling': scaling,
-            'grid': grid,
             'resolver': resolver,
             'Sampler': sampler,
             'imscale': size_deg,
             'size': size_deg,
             'pixels': pixels}
-        response = self._submit_form(input, cache=cache)
+        response = self._submit_form(input, cache=cache, get_query_payload=get_query_payload)
+        if get_query_payload:
+            return response
         urls = self._parse_response(response)
         return urls
 
@@ -298,10 +293,10 @@ class SkyViewClass(BaseQuery):
             response = self._request('GET', self.URL, cache=False)
             response.raise_for_status()
             page = BeautifulSoup(response.content, "html.parser")
-            surveys = page.findAll('select', {'name': 'survey'})
+            surveys = page.find_all('select', {'name': 'survey'})
 
             self._survey_dict = {
-                sel['id']: [x.text for x in sel.findAll('option')]
+                sel['id']: [x.text for x in sel.find_all('option')]
                 for sel in surveys
                 if 'overlay' not in sel['id']
             }
