@@ -29,17 +29,18 @@ __all__ = ['parse_coordinates',
            'TableList',
            'suppress_vo_warnings',
            'validate_email',
-           'ASTROPY_LT_4_3',
-           'ASTROPY_LT_5_0',
-           'ASTROPY_LT_5_1']
-
-ASTROPY_LT_4_3 = not minversion('astropy', '4.3')
-ASTROPY_LT_5_0 = not minversion('astropy', '5.0')
+           'ASTROPY_LT_5_1',
+           'ASTROPY_LT_5_3',
+           'ASTROPY_LT_6_0',
+           'ASTROPY_LT_7_1_1']
 
 ASTROPY_LT_5_1 = not minversion('astropy', '5.1')
+ASTROPY_LT_5_3 = not minversion('astropy', '5.3')
+ASTROPY_LT_6_0 = not minversion('astropy', '6.0')
+ASTROPY_LT_7_1_1 = not minversion('astropy', '7.1.1')
 
 
-def parse_coordinates(coordinates):
+def parse_coordinates(coordinates, *, return_frame=None):
     """
     Takes a string or astropy.coordinates object. Checks if the
     string is parsable as an `astropy.coordinates`
@@ -50,6 +51,10 @@ def parse_coordinates(coordinates):
     ----------
     coordinates : str or `astropy.coordinates` object
         Astronomical coordinate
+    return_frame : `astropy.coordinates` frame
+        The frame to return the coordinates in. If None and ``coordinates`` is
+        a string, the frame will be ICRS. If ``coordinates`` is an `astropy.coordinates` object, the
+        frame will be the same as the input object.
 
     Returns
     -------
@@ -73,8 +78,7 @@ def parse_coordinates(coordinates):
                           "appropriate astropy.coordinates object.", InputWarning)
             raise u.UnitsError
         except ValueError as err:
-            if ((ASTROPY_LT_5_0 and isinstance(err.args[1], u.UnitsError))
-                    or (not ASTROPY_LT_5_0 and isinstance(err.__context__, u.UnitsError))):
+            if isinstance(err.__context__, u.UnitsError):
                 try:
                     c = SkyCoord(coordinates, unit="deg", frame="icrs")
                     warnings.warn("Coordinate string is being interpreted as an "
@@ -93,6 +97,11 @@ def parse_coordinates(coordinates):
             c = SkyCoord(coordinates)
     else:
         raise TypeError("Argument cannot be parsed as a coordinate")
+
+    # Convert to requested frame, if given
+    if return_frame and c.frame.name != return_frame.lower():
+        c = c.transform_to(return_frame)
+
     return c
 
 
