@@ -27,14 +27,18 @@ class TapTableMeta:
         self.name = None
         self.schema = None
         self.description = None
+        self.size_bytes = 0
 
     def get_qualified_name(self):
         """Returns the qualified TAP table name. I.e. schema+table
 
         Returns
         -------
-        The the qualified TAP table name (schema+table)
+        The qualified TAP table name (schema+table)
         """
+        if '.' in self.name:
+            return self.name
+
         return f"{self.schema}.{self.name}"
 
     def add_column(self, tap_column):
@@ -50,4 +54,5 @@ class TapTableMeta:
     def __str__(self):
         return f"TAP Table name: {self.get_qualified_name()}" \
             f"\nDescription: {self.description}" \
+            f"\nSize (bytes): {self.size_bytes}" \
             f"\nNum. columns: {len(self.columns)}"
