@@ -14,18 +14,13 @@ Created on 30 jun. 2016
 
 
 """
-import os
+from pathlib import Path
+
 import pytest
 
 from astroquery.utils.tap.model.job import Job
 from astroquery.utils.tap.conn.tests.DummyConnHandler import DummyConnHandler
 from astroquery.utils.tap.conn.tests.DummyResponse import DummyResponse
-from astroquery.utils.tap.xmlparser import utils
-
-
-def data_path(filename):
-    data_dir = os.path.join(os.path.dirname(__file__), 'data')
-    return os.path.join(data_dir, filename)
 
 
 def test_job_basic():
@@ -41,13 +36,8 @@ def test_job_get_results(capsys, tmpdir):
     outputFormat = "votable"
     job.jobid = jobid
     job.parameters['format'] = outputFormat
-    responseCheckPhase = DummyResponse()
-    responseCheckPhase.set_status_code(500)
-    responseCheckPhase.set_message("ERROR")
-    responseCheckPhase.set_data(method='GET',
-                                context=None,
-                                body='FINISHED',
-                                headers=None)
+    responseCheckPhase = DummyResponse(500)
+    responseCheckPhase.set_data(method='GET', body='FINISHED')
     waitRequest = f"async/{jobid}/phase"
     connHandler = DummyConnHandler()
     connHandler.set_response(waitRequest, responseCheckPhase)
@@ -57,16 +47,10 @@ def test_job_get_results(capsys, tmpdir):
         job.get_results()
 
     responseCheckPhase.set_status_code(200)
-    responseCheckPhase.set_message("OK")
-    responseGetData = DummyResponse()
-    responseGetData.set_status_code(500)
-    responseGetData.set_message("ERROR")
-    jobContentFileName = data_path('result_1.vot')
-    jobContent = utils.read_file_content(jobContentFileName)
-    responseGetData.set_data(method='GET',
-                             context=None,
-                             body=jobContent,
-                             headers=None)
+    responseGetData = DummyResponse(500)
+    responseGetData.set_data(
+        method="GET",
+        body=(Path(__file__).with_name("data") / "result_1.vot").read_text())
     dataRequest = f"async/{jobid}/results/result"
     connHandler.set_response(dataRequest, responseGetData)
 
@@ -74,7 +58,6 @@ def test_job_get_results(capsys, tmpdir):
         job.get_results()
 
     responseGetData.set_status_code(200)
-    responseGetData.set_message("OK")
     res = job.get_results()
     assert len(res) == 3
     assert len(res.columns) == 4
@@ -100,22 +83,19 @@ def test_job_phase():
     job.set_phase("COMPLETED")
     try:
         job.set_phase("RUN")
-        pytest.fail("Exception expected. " +
-                  "Phase cannot be changed for a finished job")
+        pytest.fail("Exception expected. Phase cannot be changed for a finished job")
     except ValueError:
         # ok
         pass
     try:
         job.start()
-        pytest.fail("Exception expected. " +
-                  "A job in 'COMPLETE' phase cannot be started")
+        pytest.fail("Exception expected. A job in 'COMPLETE' phase cannot be started")
     except ValueError:
         # ok
         pass
     try:
         job.abort()
-        pytest.fail("Exception expected. " +
-                  "A job in 'COMPLETE' phase cannot be aborted")
+        pytest.fail("Exception expected. A job in 'COMPLETE' phase cannot be aborted")
     except ValueError:
         # ok
         pass
