@@ -21,6 +21,10 @@ import os
 
 def get_package_data():
     paths = [os.path.join('data', '*.data'),
-             os.path.join('data', '*.xml')
+             os.path.join('data', '*.xml'),
+             os.path.join('data', '*.json'),
+             os.path.join('data', '*.csv'),
+             os.path.join('data', '*.ecsv'),
+             os.path.join('data', '*.vot')
              ]
     return {'astroquery.utils.tap.xmlparser.tests': paths}
