@@ -45,7 +45,9 @@ def test_class_or_instance():
     assert SimpleQueryClass.query() == "class"
     U = SimpleQueryClass()
     assert U.query() == "instance"
-    assert SimpleQueryClass.query.__doc__ == " docstring "
+    # Indent changes in Python 3.13 thus cannot equate
+    # See https://github.com/python/cpython/issues/81283
+    assert "docstring" in SimpleQueryClass.query.__doc__
 
 
 @pytest.mark.parametrize(('coordinates'),
@@ -78,6 +80,30 @@ def test_parse_coordinates_4():
     assert c.to_string() == coordinates
 
 
+def test_parse_coordinates_return_frame():
+    # String input should return in icrs frame
+    coords = commons.parse_coordinates('266.40498829 -28.93617776')
+    assert coords.frame.name == 'icrs'
+
+    # SkyCoord input without return_frame should return in original frame
+    galactic = coord.SkyCoord('0 0', unit='deg', frame='galactic')
+    coords = commons.parse_coordinates(galactic)
+    assert coords.frame.name == 'galactic'
+
+    # Parse a SkyCoord in galactic frame into icrs frame
+    galactic = coord.SkyCoord('0 0', unit='deg', frame='galactic')
+    icrs = galactic.transform_to('icrs')  # Expected result
+    coords = commons.parse_coordinates(galactic, return_frame='icrs')
+    assert icrs.ra.deg == coords.ra.deg
+    assert icrs.dec.deg == coords.dec.deg
+    assert galactic.frame.name == 'galactic'
+    assert coords.frame.name == 'icrs'
+
+    # ValueError if transformation fails
+    with pytest.raises(ValueError):
+        coords = commons.parse_coordinates(galactic, return_frame='invalid')
+
+
 col_1 = [1, 2, 3]
 col_2 = [0, 1, 0, 1, 0, 1]
 col_3 = ['v', 'w', 'x', 'y', 'z']
@@ -353,9 +379,8 @@ def patch_getreadablefileobj(request):
     _is_url = aud._is_url
     aud._is_url = lambda x: True
 
-    if not commons.ASTROPY_LT_4_3:
-        _try_url_open = aud._try_url_open
-        aud._try_url_open = lambda x, **kwargs: MockRemote(x, **kwargs)
+    _try_url_open = aud._try_url_open
+    aud._try_url_open = lambda x, **kwargs: MockRemote(x, **kwargs)
 
     _urlopen = urllib.request.urlopen
     _urlopener = urllib.request.build_opener
@@ -405,8 +430,7 @@ def patch_getreadablefileobj(request):
     def closing():
         aud._is_url = _is_url
 
-        if not commons.ASTROPY_LT_4_3:
-            aud._try_url_open = _try_url_open
+        aud._try_url_open = _try_url_open
 
         urllib.request.urlopen = _urlopen
         aud.urllib.request.urlopen = _urlopen
