@@ -26,7 +26,7 @@ def parse_cs(ivoid, *, cap_index=1):
     """Return test query pars as dict for given IVO ID and capability index."""
 
     # Production server.
-    url = ("https://vao.stsci.edu/regtap/tapservice.aspx/sync?lang=adql&"
+    url = ("https://mast.stsci.edu/vo-tap/api/v0.1/registry/sync?lang=ADQL&"
            "query=select%20detail_xpath%2Cdetail_value%20from%20"
            "rr.res_detail%20where%20"
            "ivoid%3D%27{0}%27%20and%20cap_index={1}%20and%20"
