@@ -19,7 +19,7 @@ class TestVista:
     @pytest.mark.dependency(name='vsa_up')
     def test_is_vsa_up(self):
         try:
-            vista._request("GET", "http://horus.roe.ac.uk:8080/vdfs/VgetImage_form.jsp")
+            vista._request("GET", "http://vsa.roe.ac.uk:8080/vdfs/VgetImage_form.jsp")
         except Exception as ex:
             pytest.fail("VISTA appears to be down.  Exception was: {0}".format(ex))
 
